@@ -1,7 +1,7 @@
 package List::Util::Uniq;
 
-our $DATE = '2018-02-21'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2018-03-06'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,8 +49,13 @@ sub uniq_ci {
     my @res;
 
     my %mem;
+    my $undef_added;
     for (@_) {
-        push @res, $_ unless $mem{lc $_}++;
+        if (defined) {
+            push @res, $_ unless $mem{lc $_}++;
+        } else {
+            push @res, $_ unless $undef_added++;
+        }
     }
     @res;
 }
@@ -70,7 +75,15 @@ List::Util::Uniq - List utilities related to finding unique items
 
 =head1 VERSION
 
-This document describes version 0.001 of List::Util::Uniq (from Perl distribution List-Util-Uniq), released on 2018-02-21.
+This document describes version 0.002 of List::Util::Uniq (from Perl distribution List-Util-Uniq), released on 2018-03-06.
+
+=head1 SYNOPSIS
+
+ use List::Util::Uniq qw(uniq_adj uniq_adj_ci uniq_ci);
+
+ @res = uniq_adj(1, 4, 4, 3, 1, 1, 2); # 1, 4, 3, 1, 2
+ @res = uniq_adj_ci("a", "b", "B", "c", "a"); # "a", "b", "c", "a"
+ @res = uniq_ci("a", "b", "B", "c", "a"); # "a", "b", "c"
 
 =head1 FUNCTIONS
 
@@ -79,9 +92,8 @@ Not exported by default but exportable.
 =head2 uniq_adj(@list) => LIST
 
 Remove I<adjacent> duplicates from list, i.e. behave more like Unix utility's
-B<uniq> instead of L<List::MoreUtils>'s C<uniq> function, e.g.
-
- my @res = uniq(1, 4, 4, 3, 1, 1, 2); # 1, 4, 3, 1, 2
+B<uniq> instead of L<List::MoreUtils>'s C<uniq> function. Uses string equality
+test.
 
 =head2 uniq_adj_ci(@list) => LIST
 
@@ -109,6 +121,8 @@ feature.
 
 =head1 SEE ALSO
 
+L<List::Util>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
